@@ -1,4 +1,4 @@
-package Netstack::Connector::Role;
+package Firewall::Connector::Role;
 
 #------------------------------------------------------------------------------
 # 加载扩展模块
@@ -12,7 +12,7 @@ use namespace::autoclean;
 use Mojo::Util qw/dumper/;
 
 #------------------------------------------------------------------------------
-# 继承 Netstack::Config::Connector::Role 必须实现的方法
+# 继承 Netstack::Connector::Role 必须实现的方法
 #------------------------------------------------------------------------------
 requires '_buildPrompt';
 requires '_buildCommands';
@@ -21,7 +21,7 @@ requires '_buildBufferCode';
 requires 'runCommands';
 
 #------------------------------------------------------------------------------
-# 定义设备联结 Netstack::Config::Connector::Role 方法属性
+# 定义设备联结 Netstack::Connector::Role 方法属性
 #------------------------------------------------------------------------------
 has exp => (
   is      => 'ro',
@@ -198,7 +198,7 @@ sub login {
 #------------------------------------------------------------------------------
 sub _spawn_command {
   my ( $self, $args ) = @_;
-  $args //= '';
+  $args //= '-o PreferredAuthentications=password';
   # 初始化变量
   my $command;
 
@@ -303,7 +303,7 @@ sub send {
 }
 
 #------------------------------------------------------------------------------
-# 具体实现 waitfor，自动交互式执行脚本 | MORE 命令交互式输入 RT需要调整策略
+# 具体实现 waitfor，自动交互式执行脚本
 #------------------------------------------------------------------------------
 sub waitfor {
   my $self = shift;
@@ -314,17 +314,22 @@ sub waitfor {
 
   # 初始化缓存代码
   my $codeARef = [];
-  my $mapping  = $self->bufferCode;
-  # 遍历字典
-  while ( my ( $wait, $action ) = each $mapping->%* ) {
+  my $mapping  = $self->bufferCode();
+
+  # 捕捉 more 交互式 code
+  push $codeARef->@*, [
+    $mapping->{more} => sub {
+      $buff .= $exp->before;
+      $exp->send(' ');
+      exp_continue;
+    }
+  ] if exists $mapping->{more};
+
+  # 遍历其他交互式字典映射
+  while ( my ( $wait, $action ) = each $mapping->{interact}->%* ) {
     push $codeARef->@*, [
       $wait => sub {
-        # if ($wait =~ /more/i) {
-        #   $buff .= $exp->before;
-        # }
-        # else {
         $buff .= $exp->before . $exp->match;
-        # }
         $exp->send($action);
         exp_continue;
       }
@@ -338,7 +343,6 @@ sub waitfor {
   ];
 
   # 动态加载交互式代码
-  say dumper $codeARef;
   my @ret = $self->expect( 15, $codeARef->@* );
   # 异常捕捉
   if ( defined $ret[1] ) {
@@ -385,7 +389,7 @@ sub getConfig {
 #------------------------------------------------------------------------------
 sub execCommands {
   my ( $self, @commands ) = @_;
-  @commands = reverse @commands;
+
   # 判断是否已登陆设备
   if ( $self->status == 0 ) {
     $self->login;
@@ -415,7 +419,7 @@ sub execCommands {
   # 初始化 commands 属性
   $self->setCommands( \@commands );
   # 遍历接受到的命令行
-  while ( my $cmd = pop @{$self->commands} ) {
+  while ( my $cmd = shift $self->commands->@* ) {
     # 自动跳过空白行
     next if $cmd =~ /^\s*$/;
     # 执行具体的脚本
